==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: "Administración"

, "Standard IMAP"
: "IMAP estándar"

, "Standard SMTP"
: "SMTP estándar"

, "Imap"
: "Imap"

, "Hostname"
: "Nombre del Dominio"

, "Username"
: "Nombre de usuario"

, "Password"
: "Contraseña"

, "Port"
: "Puerto"

, "Secure Connection"
: "Conexión Segura"

, "None"
: "Ninguno"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Usar cuenta del sistema"

, "No"
: "No"

, "Yes"
: "Si"

, "Append domain to login name"
: "Anexar dominio para iniciar sesión Nombre"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Admin Cyrus"

, "Cyrus Admin Password"
: "Contraseña Admin Cyrus"

, "Use proxy auth"
: "Utilizar autorizacion de proxy"

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentificación"

, "Login"
: "Ingreso"

, "Plain"
: "Plano"

, "Primary Domain"
: "Dominio Primario"

, "Secondary Domains (comma separated)"
: "Dominios secundarios (separados por coma)"

, "Notifications service address"
: "Dirección del servicio de notificaciones"

, "Notification Username"
: "Notificación Nombre de Usuario"

, "Notification Password"
: "Notificación Contraseña"

, "Notifications local client (hostname or IP address)"
: "Notificaciones cliente local (nombre de host o IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Dominio de MySql"

, "MySql Database"
: "Base de Datos MySql"

, "MySql User"
: "Usuario MySql"

, "MySql Password"
: "Contraseña MySql"

, "MySql Port"
: "Puerto MySql"

, "User or UID"
: "Usuario o UID"

, "Group or GID"
: "Grupo o GID"

, "Home Template"
: "Plantilla Home"

, "Password Scheme"
: "Esquema de contraseña"

, "PLAIN-MD5"
: "PLANO-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLANO"

, "I have read the license agreement and accept it"
: "He leído los términos de la licencia y estoy de acuerdo con ellos"

, "License Agreement"
: "Términos de Licenciamiento"

, "I have read the privacy agreement and accept it"
: "He leído la política de privacidad y estoy de acuerdo con ella"

, "Privacy Agreement"
: "Política de Privacidad"

, "Accept Terms and Conditions"
: "Aceptar Términos y Condiciones"

, "Performing Environment Checks..."
: "Realizando controles de entorno..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "No se puede encontrar ningun resultado de {0}. Por favor, intenta modificar tus criterios de filtro, opciones de vista o de {1} que estaba buscando."

, "Check"
: "Verificar"

, "Result"
: "Resultado"

, "Error"
: "Error"

, "Run setup tests"
: "Realizar pruebas de instalación"

, "Ignore setup tests"
: "Ignorar pruebas de instalación"

, "Install application"
: "Instalar aplicación"

, "File"
: "Fichero"

, "Setup Authentication"
: "Autentificación del Instalador"

, "Database"
: "Base de Datos"

, "User"
: "Usuario"

, "Prefix"
: "Prefijo"

, "Logging"
: "Registros de sucesos"

, "Filename"
: "Nombre de archivo"

, "Priority"
: "Prioridad"

, "Caching"
: "Cacheo"

, "Lifetime (seconds)"
: "Tiempo de vida (segundos)"

, "Path"
: "Ruta"

, "Queue"
: "Cola"

, "Session"
: "Sesión"

, "Temporary files"
: "Archivos temporales"

, "Temporary Files Path"
: "Ruta de Archivos Temporales"

, "Filestore directory"
: "Directorio Almacén de ficheros"

, "Filestore Path"
: "Ruta Almacén de ficheros"

, "Addressbook Map panel"
: "Panel de la Libreta de direcciones"

, "Map panel"
: "Panel del Mapa"

, "disabled"
: "deshabilitado"

, "enabled"
: "habilitado"

, "Config file is not writable"
: "El archivo de configuración no tiene permisos de escritura"

, "Save config"
: "Guardar configuración"

, "Download config file"
: "Descargando archivo de configuración"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: "Términos y Condiciones"

, "Setup Checks"
: "Pruebas de Instalación"

, "Config Manager"
: "Administrador de Configuración"

, "Authentication/Accounts"
: "Autentificación/Cuentas"

, "Email"
: "Email"

, "Application Manager"
: "Administrador de Aplicaciones"

, "Delete all existing users and groups"
: "Borrar todos los usuarios y grupos existentes"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Cambiar desde SQL a LDAP borrará todas las cuentas, cargos y grupos de usuario. ¿Realmente desea cambiar el almacenamiento de cuentas administrativo a LDAP?"

, "TLS client certificate"
: "Certificado TLS Cliente"

, "Initial Admin User"
: "Usuario Administrador Inicial"

, "Initial admin login name"
: "Nombre inicial de ingreso de administrador"

, "Initial admin Password"
: "Contraseña inicial de ingreso de administrador"

, "Password confirmation"
: "Confirmación de contraseñ"

, "Authentication provider"
: "Proveedor de autentificación"

, "Try to split username"
: "Trate de dividir nombre de usuario"

, "Account canonical form"
: "Formulación de cuenta canónica"

, "Account domain name"
: "Nombre de la cuenta de dominio"

, "Account domain short name"
: "Cuenta de dominio nombre corto"

, "Host"
: "Dominio"

, "Login name"
: "Nombre de ingreso"

, "Bind requires DN"
: "Bind requiere DN"

, "Start TLS"
: "Start TLS"

, "Base DN"
: "Base DN"

, "Search filter"
: "Buscar filtro"

, "Certificate validation"
: "Validación con Certificado"

, "CA file"
: "Archivo CA"

, "CRL directory"
: "Directorio CRL"

, "Accounts storage"
: "Almacenamiento de cuentas"

, "Default user group name"
: "Nombre predeterminado del grupo de usuarios"

, "Default admin group name"
: "Nombre predeterminado del grupo de administradores"

, "Login panel"
: "Panel de Login"

, "Reuse last username logged"
: "Utilizar último Usuario conectado"

, "Password Settings"
: "Preferencias de Contraseña"

, "User can change password"
: "Usuario puede cambiar su contraseña"

, "Enable password policy"
: "Habilitar política de contraseñas"

, "Only ASCII"
: "solo ASCII"

, "Minimum length"
: "Logitud Mínima"

, "Minimum word chars"
: "Caracteres mínimos por palabra"

, "Minimum uppercase chars"
: "Caracteres mínimos en mayúsculas"

, "Minimum special chars"
: "Caracteres mínimos especiales"

, "Minimum numbers"
: "Números mínimos "

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Prohibir parte del nombre de usuario en la contraseña"

, "Redirect Settings"
: "Configuración de redirección"

, "Redirect Url (redirect to login screen if empty)"
: "URL de redireccionamiento (redirección a Login si está vacío)"

, "Redirect Always (if No, only redirect after logout)"
: "Redireccionar siempre (si no, sólo redirigir después de cerrar la sesión)"

, "Redirect to referring site, if exists"
: "Redirigir al sitio de referencia, si es que existe"

, "Password encoding"
: "Codificación de contraseña"

, "des"
: "des"

, "crypt"
: "encriptar"

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "plano"

, "User DN"
: "Usuario DN"

, "User Filter"
: "Filtrar usuario"

, "User Search Scope"
: "Usuario ámbito de búsqueda"

, "Groups DN"
: "Grupos DN"

, "Group Filter"
: "Filtrar Grupo"

, "Group Search Scope"
: "Grupo ámbito de búsqueda"

, "Use Rfc 2307 bis"
: "Usar Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Mantener atributos RFC 2307"

, "Min User Id"
: "Id Mínimo de Usuario"

, "Max User Id"
: "ID Máximo de Usuario"

, "Min Group Id"
: "Id de Grupo Mínimo de Usuario"

, "Max Group Id"
: "Id de Grupo Máximo de Usuario"

, "Group UUID Attribute name"
: "Nombre del atributo del grupo UUID"

, "User UUID Attribute name"
: "Nombre del atributo del usuario UUID"

, "Readonly access"
: "Acceso solo Lectura"

, "Save config and install"
: "Guardar configuración e instalar"

, "Passwords don't match"
: "Las contraseñas no coinciden"

, "Should not be empty"
: "No debería estar vacío"

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplicación"
 ,"Aplicaciones"

]
, "Name"
: "Nombre"

, "Enabled"
: "Activado"

, "Order"
: "Ordenar"

, "Installed Version"
: "Versión Instalado"

, "Available Version"
: "Versión Disponible"

, "Status"
: "Estado"

, "Depends on"
: "Depende de"

, "Uninstall application"
: "Desinstalar aplicación"

, "Update application"
: "Actualizar aplicación"

, "Go to {0} login"
: "Ir al {0} de ingreso"

, "uninstall"
: "desinstalar"

, "Do you really want to uninstall the application(s)?"
: "¿Realmente desea desinstalar la(s) aplicación(es)?"

, "This may take a while"
: "Puede tomar algún tiempo"

, "Dependency Violation"
: "Violación de Dependencia"

, "CLI Required"
: "CLI Requerido"

, "Application"
: "Aplicación"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "He leído los términos de la licencia y estoy de acuerdo con ellos"

, "License Agreement"
: "Términos de Licenciamiento"

, "I have read the privacy agreement and accept it"
: "He leído la política de privacidad y estoy de acuerdo con ella"

, "Privacy Agreement"
: "Política de Privacidad"

, "Accept Terms and Conditions"
: "Aceptar Términos y Condiciones"

, "Backend"
: "Administración"

, "Standard IMAP"
: "IMAP estándar"

, "Standard SMTP"
: "SMTP estándar"

, "Imap"
: "Imap"

, "Hostname"
: "Nombre del Dominio"

, "Username"
: "Nombre de usuario"

, "Password"
: "Contraseña"

, "Port"
: "Puerto"

, "Secure Connection"
: "Conexión Segura"

, "None"
: "Ninguno"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Usar cuenta del sistema"

, "No"
: "No"

, "Yes"
: "Si"

, "Append domain to login name"
: "Anexar dominio para iniciar sesión Nombre"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Admin Cyrus"

, "Cyrus Admin Password"
: "Contraseña Admin Cyrus"

, "Use proxy auth"
: "Utilizar autorizacion de proxy"

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentificación"

, "Login"
: "Ingreso"

, "Plain"
: "Plano"

, "Primary Domain"
: "Dominio Primario"

, "Secondary Domains (comma separated)"
: "Dominios secundarios (separados por coma)"

, "Notifications service address"
: "Dirección del servicio de notificaciones"

, "Notification Username"
: "Notificación Nombre de Usuario"

, "Notification Password"
: "Notificación Contraseña"

, "Notifications local client (hostname or IP address)"
: "Notificaciones cliente local (nombre de host o IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Dominio de MySql"

, "MySql Database"
: "Base de Datos MySql"

, "MySql User"
: "Usuario MySql"

, "MySql Password"
: "Contraseña MySql"

, "MySql Port"
: "Puerto MySql"

, "User or UID"
: "Usuario o UID"

, "Group or GID"
: "Grupo o GID"

, "Home Template"
: "Plantilla Home"

, "Password Scheme"
: "Esquema de contraseña"

, "PLAIN-MD5"
: "PLANO-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLANO"

, "Terms and Conditions"
: "Términos y Condiciones"

, "Setup Checks"
: "Pruebas de Instalación"

, "Config Manager"
: "Administrador de Configuración"

, "Authentication/Accounts"
: "Autentificación/Cuentas"

, "Email"
: "Email"

, "Application Manager"
: "Administrador de Aplicaciones"

, "Setup"
: ""

, "Name"
: "Nombre"

, "Enabled"
: "Activado"

, "Order"
: "Ordenar"

, "Installed Version"
: "Versión Instalado"

, "Available Version"
: "Versión Disponible"

, "Status"
: "Estado"

, "Depends on"
: "Depende de"

, "Install application"
: "Instalar aplicación"

, "Uninstall application"
: "Desinstalar aplicación"

, "Update application"
: "Actualizar aplicación"

, "Go to {0} login"
: "Ir al {0} de ingreso"

, "uninstall"
: "desinstalar"

, "Do you really want to uninstall the application(s)?"
: "¿Realmente desea desinstalar la(s) aplicación(es)?"

, "This may take a while"
: "Puede tomar algún tiempo"

, "Dependency Violation"
: "Violación de Dependencia"

, "CLI Required"
: "CLI Requerido"

, "Delete all existing users and groups"
: "Borrar todos los usuarios y grupos existentes"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Cambiar desde SQL a LDAP borrará todas las cuentas, cargos y grupos de usuario. ¿Realmente desea cambiar el almacenamiento de cuentas administrativo a LDAP?"

, "TLS client certificate"
: "Certificado TLS Cliente"

, "Initial Admin User"
: "Usuario Administrador Inicial"

, "Initial admin login name"
: "Nombre inicial de ingreso de administrador"

, "Initial admin Password"
: "Contraseña inicial de ingreso de administrador"

, "Password confirmation"
: "Confirmación de contraseñ"

, "Authentication provider"
: "Proveedor de autentificación"

, "Try to split username"
: "Trate de dividir nombre de usuario"

, "Account canonical form"
: "Formulación de cuenta canónica"

, "Account domain name"
: "Nombre de la cuenta de dominio"

, "Account domain short name"
: "Cuenta de dominio nombre corto"

, "Host"
: "Dominio"

, "Login name"
: "Nombre de ingreso"

, "Bind requires DN"
: "Bind requiere DN"

, "Start TLS"
: "Start TLS"

, "Base DN"
: "Base DN"

, "Search filter"
: "Buscar filtro"

, "Certificate validation"
: "Validación con Certificado"

, "CA file"
: "Archivo CA"

, "CRL directory"
: "Directorio CRL"

, "Accounts storage"
: "Almacenamiento de cuentas"

, "Default user group name"
: "Nombre predeterminado del grupo de usuarios"

, "Default admin group name"
: "Nombre predeterminado del grupo de administradores"

, "Login panel"
: "Panel de Login"

, "Reuse last username logged"
: "Utilizar último Usuario conectado"

, "Password Settings"
: "Preferencias de Contraseña"

, "User can change password"
: "Usuario puede cambiar su contraseña"

, "Enable password policy"
: "Habilitar política de contraseñas"

, "Only ASCII"
: "solo ASCII"

, "Minimum length"
: "Logitud Mínima"

, "Minimum word chars"
: "Caracteres mínimos por palabra"

, "Minimum uppercase chars"
: "Caracteres mínimos en mayúsculas"

, "Minimum special chars"
: "Caracteres mínimos especiales"

, "Minimum numbers"
: "Números mínimos "

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Prohibir parte del nombre de usuario en la contraseña"

, "Redirect Settings"
: "Configuración de redirección"

, "Redirect Url (redirect to login screen if empty)"
: "URL de redireccionamiento (redirección a Login si está vacío)"

, "Redirect Always (if No, only redirect after logout)"
: "Redireccionar siempre (si no, sólo redirigir después de cerrar la sesión)"

, "Redirect to referring site, if exists"
: "Redirigir al sitio de referencia, si es que existe"

, "Password encoding"
: "Codificación de contraseña"

, "des"
: "des"

, "crypt"
: "encriptar"

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "plano"

, "User DN"
: "Usuario DN"

, "User Filter"
: "Filtrar usuario"

, "User Search Scope"
: "Usuario ámbito de búsqueda"

, "Groups DN"
: "Grupos DN"

, "Group Filter"
: "Filtrar Grupo"

, "Group Search Scope"
: "Grupo ámbito de búsqueda"

, "Use Rfc 2307 bis"
: "Usar Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Mantener atributos RFC 2307"

, "Min User Id"
: "Id Mínimo de Usuario"

, "Max User Id"
: "ID Máximo de Usuario"

, "Min Group Id"
: "Id de Grupo Mínimo de Usuario"

, "Max Group Id"
: "Id de Grupo Máximo de Usuario"

, "Group UUID Attribute name"
: "Nombre del atributo del grupo UUID"

, "User UUID Attribute name"
: "Nombre del atributo del usuario UUID"

, "Readonly access"
: "Acceso solo Lectura"

, "Save config and install"
: "Guardar configuración e instalar"

, "Save config"
: "Guardar configuración"

, "Passwords don't match"
: "Las contraseñas no coinciden"

, "Should not be empty"
: "No debería estar vacío"

, "Performing Environment Checks..."
: "Realizando controles de entorno..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "No se puede encontrar ningun resultado de {0}. Por favor, intenta modificar tus criterios de filtro, opciones de vista o de {1} que estaba buscando."

, "Check"
: "Verificar"

, "Result"
: "Resultado"

, "Error"
: "Error"

, "Run setup tests"
: "Realizar pruebas de instalación"

, "Ignore setup tests"
: "Ignorar pruebas de instalación"

, "Application, Applications"
: [
  "Aplicación"
 ,"Aplicaciones"

]
, "File"
: "Fichero"

, "Setup Authentication"
: "Autentificación del Instalador"

, "Database"
: "Base de Datos"

, "User"
: "Usuario"

, "Prefix"
: "Prefijo"

, "Logging"
: "Registros de sucesos"

, "Filename"
: "Nombre de archivo"

, "Priority"
: "Prioridad"

, "Caching"
: "Cacheo"

, "Lifetime (seconds)"
: "Tiempo de vida (segundos)"

, "Path"
: "Ruta"

, "Queue"
: "Cola"

, "Session"
: "Sesión"

, "Temporary files"
: "Archivos temporales"

, "Temporary Files Path"
: "Ruta de Archivos Temporales"

, "Filestore directory"
: "Directorio Almacén de ficheros"

, "Filestore Path"
: "Ruta Almacén de ficheros"

, "Addressbook Map panel"
: "Panel de la Libreta de direcciones"

, "Map panel"
: "Panel del Mapa"

, "disabled"
: "deshabilitado"

, "enabled"
: "habilitado"

, "Config file is not writable"
: "El archivo de configuración no tiene permisos de escritura"

, "Download config file"
: "Descargando archivo de configuración"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplicación"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
